@@ -24,16 +24,28 @@ use Inline 'C' => <<'END_OF_C_CODE';
  *   https://metacpan.org/pod/perlguts
  */
 
+/*
+ * Function: Shell()
+ * -----------------
+ */
 char* Shell() {
     char *shell = getenv("SHELL");
     return shell;
 };
 
+/*
+ * Function: User()
+ * ----------------
+ */
 char* User() {
     char *user = getenv("USER");
     return user;
 };
 
+/*
+ * Function: Logname()
+ * -------------------
+ */
 char* Logname() {
     char *logname = getenv("LOGNAME");
     return logname;
@@ -174,7 +186,7 @@ void WinSize() {
 END_OF_C_CODE
 
 # Set the package version. 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 # Base class of this module.
 our @ISA = qw(Exporter);
@@ -216,7 +228,7 @@ our @EXPORT = qw(
     cursor_down
     cursor_forward
     cursor_backward
-    inuse_terminal
+    terminal
     User
     Logname
     Shell
@@ -450,7 +462,7 @@ sub ctlseqs_request {
     if ($@) {
          # print "timedout\n";
          try {
-             # On error die.
+             # On error die. Raises an exception.
              die;
          } catch {
              # Clean up settings.  
@@ -663,7 +675,7 @@ sub cursor_forward {
 };
 
 #------------------------------------------------------------------------------# 
-# Subroutine cursor_backward                                                       #
+# Subroutine cursor_backward                                                   #
 #------------------------------------------------------------------------------# 
 sub cursor_backward {
     # Set the control sequence.
@@ -676,39 +688,39 @@ sub cursor_backward {
 # Subroutine inuse_terminal                                                    #
 # ps -o 'cmd=' -p $(ps -o 'ppid=' -p $$)                                       #
 #------------------------------------------------------------------------------# 
-sub inuse_terminal {
+sub terminal {
+    # Declare local variables.
+    my $term = undef;
+    my $shell = undef;
     # Get the terminal path.
-    my $term_path = TermPath();
-    # Extract the path id from the terminal path.
-    my $path_id = undef;
-    if ($term_path =~ /^.*\/dev\/(pts\/\d+)$/) {
-        $path_id = $1;
-    };
-    my $shell_path = Shell();
-    # Extract the path id from the terminal path.
-    my $shell_id = undef;
-    if ($shell_path =~ /^.*\/([a-zA-Z]+)$/) {
-        $shell_id = $1;
-    };
+    my $tpath = TermPath();
+    # Extract the pts from the terminal path.
+    ($term) = $tpath =~ /^.*\/dev\/(pts\/\d+)$/;
+    # Extract the shell from the shell path
+    my $tshell = Shell();
+    ($shell) = $tshell =~ /^.*\/(.*)$/;
     # Add square brackets for use of grep.
-    substr($path_id, 0, 0) = '['; substr($path_id, 2, 0) = ']';
-    substr($shell_id, 0, 0) = '['; substr($shell_id, 2, 0) = ']';
+    substr($term, 0, 0) = '[';
+    substr($term, 2, 0) = ']';
+    substr($shell, 0, 0) = '[';
+    substr($shell, 2, 0) = ']';
     # Filter process by shell and pts.
-    my $process = `ps aux |grep $shell_id| grep $path_id`;  
-    # Split up the process by white spaces.
-    my @fields = split /\s+/, $process;
+    my $process = `ps aux |grep $shell| grep $term`;
+    # Split up the process by lines and white spaces.
+    my @lines = split /\n/, $process;
+    my @columns = split /\s+/, $lines[0];
     # Extract the PID from the array.
-    my $pid = $fields[1];
+    my $pid = $columns[1];
     # Get the PPID from the command ps.
     my $ppid = `ps -o 'ppid=' -p $pid`;
     # Trim the PPID.  
     $ppid =~ s/^\s+|\s+$//g;
     # Get the terminal in use from the command ps.
-    my $terminal = `ps -o 'cmd=' -p $ppid`;
+    my $this_term = `ps -o 'cmd=' -p $ppid`;
     # Trim the terminal variable.  
-    $terminal =~ s/^\s+|\s+$//g;
+    $this_term =~ s/^\s+|\s+$//g;
     # Return the terminal in use.
-    return $terminal;
+    return $this_term;
 };
 
 1;
@@ -756,7 +768,7 @@ Terminal::Control - Perl extension with methods for the control of the terminal
   cursor_up();
   cursor_down(); 
   cursor_forward(); 
-  cursor_back(); 
+  cursor_backward(); 
 
   # Show or hide the cursor on the terminal window.
   
@@ -868,7 +880,7 @@ The methods below are sorted according to their logical relationship.
 
 =item * cursor_forward()
 
-=item * cursor_back()
+=item * cursor_backward()
 
 =back
 
@@ -972,9 +984,6 @@ B<echo_off()>
 Turn the echo off. The method uses for the moment the Shell command C<stty> for 
 turning the echo of (user) input off. 
 
-Variables in square brackets in the method call are optional. They are in the
-related method predefined.
-
 B<cursor_up()>
 
 Cursor up.
@@ -1007,6 +1016,9 @@ B<TermPath()>
 
 Path ot terminal.
 
+Variables in square brackets in the method call are optional. They are in the
+related method predefined.
+
 =head1 ERROR CODES
 
 The error codes of methods which are related to getting the window or sreen
@@ -1090,11 +1102,11 @@ size are as follows:
 
 =head2 Working example for cursor movement
 
-home position.The script works as follows. The terminal window is reseted.
-Then the position of the cursor is set to (20, 40) on the terminal window.
-Now the user can use the the arrow keys on the keyboard to move the cursor
-on the terminal window. Pressing 'q' quits the loop and set the cursor
-position to (1, 1) which is be the home position.
+The script works as follows. The terminal window is reseted. Then the position
+of the cursor is set to (20, 40) on the terminal window. Now the user can use
+the the arrow keys on the keyboard to move the cursor on the terminal window.
+Pressing 'q' quits the loop and set the cursor position to (1, 1) which is be
+the home position.
 
   # Initialise variable $chr.
   my $chr = '';
@@ -1118,7 +1130,7 @@ position to (1, 1) which is be the home position.
       } elsif (ord($chr) == 67) {
           cursor_forward();
       } elsif (ord($chr) == 68) {
-          cursor_back();
+          cursor_backward();
       };
   };
 
@@ -1253,8 +1265,8 @@ Escape sequences used by the module:
 =head2 Xterm control sequences
 
 The xterm program is a terminal emulator for the X Window System. The Xterm
-escape sequences take their name from the terminal emulator of the same name.
-This means that the Xterm escape sequences should primarily be able to run
+control sequences take their name from the terminal emulator of the same name.
+This means that the Xterm control sequences should primarily be able to run
 under xterm. However, they also work with other terminal emulators.
 
 Escape sequences used by the module:
@@ -1282,14 +1294,14 @@ Terminals tested so far with the module:
 
 =over 4
 
-=item * xterm
-
-=item * ROXTerm
-
 =item * LXTerminal
 
 =item * mate-terminal
 
+=item * ROXTerm
+
+=item * xterm
+
 =back
 
 =head1 LIMITATIONS
